@@ -29,11 +29,20 @@ class JsonPatchBuilder:
         return {'patch': patch} if patch else None
 
 
+class ReadResourceBuilder:
+    def __init__(self, audit_log):
+        self.audit_log = audit_log
+
+    def build(self, resource, payload):
+        return {'resource': {k: v for k, v in resource.items() if k in ['_id', 'id']}}
+
+
 MODE_BUILDERS = {
     'diff': DiffBuilder,
     'jsonpatch': JsonPatchBuilder,
     'prev_and_new': OldAndNewBuilder,
     'old_and_new': OldAndNewBuilder,
+    'read': ReadResourceBuilder,
 }
 
 
